@@ -1,12 +1,4 @@
-"""Code for training networks.
-
-Install:
-mamba create -n das-tune python=3.8 das keras-tuner -c ncb -c conda-forge
-conda activate das-tune
-cd DAS_SOURCE_BASEDIR
-pip install -e . --upgrade --no-dependencies
-das tune --data-dir tutorial_dataset.npy --save-dir tutorial_dataset.res --nb-hist 1024 --no-ignore-boundaries --verbose 2
-"""
+"""Code for tuning the hyperparameters of a network."""
 # TODO:
 # write custom Tuner that generates datasets and overlap based nb_hist and kernel params
 # see: https://keras.io/guides/keras_tuner/custom_tuner/
@@ -41,7 +33,7 @@ class TunableModel(kt.HyperModel):
         self.params = params.copy()
 
     def build(self, hp):
-        hp.Choice('nb_filters', values=np.power(2, np.arange(3, 8)).tolist())
+        hp.Choice('nb_filters', values=np.power(2, np.arange(3, 7)).tolist())
         hp.Choice('kernel_size', values=np.power(2, np.arange(2, 7)).tolist())
         hp.Choice('learning_rate', values=[1e-2, 1e-3, 1e-4])
         hp.Choice('nb_hist', values=np.power(2, np.arange(7, 14)).tolist())
@@ -79,26 +71,24 @@ class DasTuner(kt.Tuner):
 
         # these need updating based on current hyperparameters
         self.params['stride'] = self.params['nb_hist']
-        # self.params['y_offset'] = 0
-        # self.params['sample_weight_mode'] = 'temporal'
         if self.params['ignore_boundaries']:
             self.params['data_padding'] = int(np.ceil(self.params['kernel_size'] * self.params['nb_conv']))  # this does not completely avoid boundary effects but should minimize them sufficiently
             self.params['stride'] = self.params['stride'] - 2 * self.params['data_padding']
 
         data_gen = data.AudioSequence(train_x, train_y,
-                                    shuffle=True, nb_repeats=1,
-                                    **self.params)
+                                      shuffle=True, nb_repeats=1,
+                                      **self.params)
         val_gen = data.AudioSequence(val_x, val_y,
-                                    shuffle=False,
-                                    **self.params)
-        logging.info(f"Hyperparameters:")
+                                     shuffle=False,
+                                     **self.params)
+        logging.info("Hyperparameters:")
         logging.info(trial.hyperparameters.values)
         if steps_per_epoch is None:
-            steps_per_epoch=min(len(data_gen), 1000)
+            steps_per_epoch = min(len(data_gen), 1000)
 
         model = self.hypermodel.build(trial.hyperparameters)
         model.fit(data_gen, validation_data=val_gen, epochs=epochs, steps_per_epoch=steps_per_epoch,
-                    callbacks=callbacks, verbose=verbose, class_weight=class_weight)
+                  callbacks=callbacks, verbose=verbose, class_weight=class_weight)
 
 
 def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
@@ -117,7 +107,7 @@ def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
           log_messages: bool = False, nb_stacks: int = 2, with_y_hist: bool = True,
           balance: bool = False, version_data: bool = True,
           _qt_progress: bool = False) -> Tuple[keras.Model, Dict[str, Any]]:
-    """Train a DAS network.
+    """Tune the hyperparameters of a DAS network.
 
     Args:
         data_dir (str): Path to the directory or file with the dataset for training.
@@ -295,21 +285,6 @@ def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
     else:
         shuffle_subset = None
 
-    # data_gen = data.AudioSequence(d['train']['x'], d['train']['y'],
-    #                               shuffle=True, shuffle_subset=shuffle_subset,
-    #                               first_sample=first_sample_train, last_sample=last_sample_train, nb_repeats=1,
-    #                               **params)
-    # val_gen = data.AudioSequence(d['val']['x'], d['val']['y'],
-    #                              shuffle=False, shuffle_subset=shuffle_subset,
-    #                              first_sample=first_sample_val, last_sample=last_sample_val,
-    #                              **params)
-
-
-    # logging.info(f"Training data:")
-    # logging.info(f"   {data_gen}")
-    # logging.info(f"Validation data:")
-    # logging.info(f"   {val_gen}")
-
     params['class_weights'] = None
     if balance:
         from sklearn.utils import class_weight
@@ -325,7 +300,6 @@ def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
     save_name = '{0}/{1}{2}'.format(save_dir, save_prefix, time.strftime('%Y%m%d_%H%M%S'))
     logging.info(f'Will save to {save_name}.')
 
-
     tuner = DasTuner(
         params = params,
         oracle=kt.oracles.BayesianOptimization(
@@ -340,7 +314,6 @@ def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
     logging.info(tuner.search_space_summary())
 
     utils.save_params(params, save_name)
-    # checkpoint_save_name = save_name + "_model.h5"  # this will overwrite intermediates from previous epochs
 
     callbacks = [EarlyStopping(monitor='val_loss', patience=20),]
 
@@ -350,8 +323,8 @@ def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
     if _qt_progress:
         callbacks.append(utils.QtProgressCallback(nb_epoch, _qt_progress))
 
-    # if tensorboard:
-    #     callbacks.append(TensorBoard(log_dir=save_dir))
+    if tensorboard:
+        callbacks.append(TensorBoard(log_dir=save_name))
 
     del params['neptune_api_token']
     if neptune_api_token and neptune_project:  # could also get those from env vars!
@@ -383,7 +356,6 @@ def train(*, data_dir: str, x_suffix: str = '', y_suffix: str = '',
     else:
         logging.info('re-loading last best model')
         model = tuner.get_best_models()[0]
-        # model.load_weights(checkpoint_save_name)
 
         logging.info('predicting')
         # TODO: Need to update params with best hyperparams (e.g. nb-hist)
